==> schedwisrv-0.1.4.tar.gz: schedwisrv-0.1.4/src/sql_status.h <==
/* Schedwi
   Copyright (C) 2007-2010 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* sql_status.h -- job status management functions */

#ifndef _SQL_STATUS_H
#define _SQL_STATUS_H

#include <schedwi.h>
#include <lwc_linkedlist.h>
#include <sql_common.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int sql_status_workload_list OF((lwc_LL **rows,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_get OF((int workload_date,
			unsigned long long int job_id,
			int *status,
			long int *start_time,
			int *retry_num,
			char **message,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_set OF((int workload_date,
			const char *job_id,
			int status,
			unsigned int start_time,
			int retry_num,
			const char *error_message,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_adjust_start_time OF((int workload_date,
			unsigned long long int job_id,
			unsigned int start_time,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_delete OF((int workload_date,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_get_old OF((int workload_date,
			int (*callback)(void *, const char *, int),
			void *user_data,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_copy_to_workload OF((int workload_date,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* sql_status.h */

/*-----------------============== End Of File ==============-----------------*/

==> schedwisrv-0.1.5.tar.gz: schedwisrv-0.1.5/src/sql_status.h <==
/* Schedwi
   Copyright (C) 2007-2013 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* sql_status.h -- job status management functions */

#ifndef _SQL_STATUS_H
#define _SQL_STATUS_H

#include <schedwi.h>
#include <lwc_linkedlist.h>
#include <sql_common.h>

#define WAIT_REASON_MASK_PARENT            1
#define WAIT_REASON_MASK_TIME              2
#define WAIT_REASON_MASK_LINKS             4
#define WAIT_REASON_MASK_CONSTRAINT_FILE   8
#define WAIT_REASON_MASK_MODULE           16
#define WAIT_REASON_MASK_MANUAL           32

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int sql_status_workload_list OF((lwc_LL **rows,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_get OF((int workload_date,
			unsigned long long int job_id,
			int *status,
			long int *start_time,
			int *retry_num,
			int *wait_reason,
			char **message,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_update_wait_reason OF((int workload_date,
			unsigned long long int job_id,
			int wait_reason,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_set OF((int workload_date,
			const char *job_id,
			int status,
			unsigned int start_time,
			int retry_num,
			int wait_reason,
			const char *error_message,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_adjust_start_time OF((int workload_date,
			unsigned long long int job_id,
			unsigned int start_time,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_delete OF((int workload_date,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_get_old OF((int workload_date,
			int (*callback)(void *, const char *, int),
			void *user_data,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));
extern int sql_status_copy_to_workload OF((int workload_date,
			void (*error_func)(void *, const char *, int),
			void *user_data_error_func));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* sql_status.h */

/*-----------------============== End Of File ==============-----------------*/
